@@ -10,7 +10,7 @@ import sys
 import os
 import fileinput
 import logging
-import codecs
+import io
 import csv
 
 
@@ -28,6 +28,7 @@ from Gnumed.pycommon import gmPG2
 from Gnumed.pycommon import gmMatchProvider
 from Gnumed.pycommon import gmI18N
 from Gnumed.pycommon import gmNetworkTools
+from Gnumed.pycommon.gmExceptions import ConstructorError
 
 from Gnumed.business import gmPerson
 from Gnumed.business import gmDataMining
@@ -79,19 +80,19 @@ class cPatientListingCtrl(gmListWidgets.cReportListCtrl):
 
 		_log.debug('identifier column not configured, trying to detect')
 
-		if data.has_key('pk_patient'):
+		if u'pk_patient' in data:
 			return u'pk_patient'
 
-		if data.has_key('fk_patient'):
+		if u'fk_patient' in data:
 			return u'fk_patient'
 
-		if data.has_key('pk_identity'):
+		if u'pk_identity' in data:
 			return u'pk_identity'
 
-		if data.has_key('fk_identity'):
+		if u'fk_identity' in data:
 			return u'fk_identity'
 
-		if data.has_key('id_identity'):
+		if u'id_identity' in data:
 			return u'id_identity'
 
 		return gmListWidgets.get_choices_from_list (
@@ -125,7 +126,7 @@ class cPatientListingCtrl(gmListWidgets.cReportListCtrl):
 		pat_data = data[pk_pat_col]
 		try:
 			pat_pk = int(pat_data)
-			pat = gmPerson.cIdentity(aPK_obj = pat_pk)
+			pat = gmPerson.cPerson(aPK_obj = pat_pk)
 		except (ValueError, TypeError):
 			searcher = gmPersonSearch.cPatientSearcher_SQL()
 			idents = searcher.get_identities(pat_data)
@@ -144,6 +145,9 @@ class cPatientListingCtrl(gmListWidgets.cReportListCtrl):
 					return
 				pat = dlg.get_selected_person()
 				dlg.Destroy()
+		except ConstructorError:
+			gmDispatcher.send(signal = 'statustext', msg = _('No matching patient found.'))
+			return
 
 		from Gnumed.wxpython import gmPatSearchWidgets
 		gmPatSearchWidgets.set_active_patient(patient = pat)
@@ -410,7 +414,7 @@ class cDataMiningPnl(wxgDataMiningPnl.wxgDataMiningPnl):
 		gp.ylabel(y_col)
 		try:
 			gp.plot([ [r[x_col], r[y_col]] for r in self.query_results ])
-		except StandardError:
+		except Exception:
 			_log.exception('unable to plot results from [%s:%s]' % (x_col, y_col))
 			gmDispatcher.send(signal = 'statustext', msg = _('Error plotting data.'), beep = True)
 
@@ -447,7 +451,7 @@ class cDataMiningPnl(wxgDataMiningPnl.wxgDataMiningPnl):
 
 		comment = self._PRW_report_name.GetValue().strip()
 		for item in data:
-			pat = gmPerson.cIdentity(aPK_obj = item[pat_pk_key])
+			pat = gmPerson.cPerson(aPK_obj = item[pat_pk_key])
 			pat.put_on_waiting_list (comment = comment, zone = zone)
 
 	#--------------------------------------------------------
@@ -488,7 +492,7 @@ class cDataMiningPnl(wxgDataMiningPnl.wxgDataMiningPnl):
 		if choice != wx.ID_OK:
 			return
 
-		csv_file = codecs.open(csv_name, 'w', 'utf8')
+		csv_file = io.open(csv_name, mode = 'wt', encoding = 'utf8')
 		csv_file.write(u'#-------------------------------------------------------------------------------------\n')
 		csv_file.write(u'# GNUmed SQL report results\n')
 		csv_file.write(u'#\n')
