@@ -49,18 +49,21 @@ _log = logging.getLogger('gm.ui')
 # EMR access helper functions
 #----------------------------------------------------------------
 def emr_access_spinner(time2spin=0):
-	"""Spin time in seconds."""
+	"""Spin time in seconds but let wx go on."""
 	if time2spin == 0:
 		return
-	sleep_time = 0.1
+	sleep_time = 0.1			# 100ms
 	total_rounds = int(time2spin / sleep_time)
 	if total_rounds < 1:
+		wx.Yield()
+		time.sleep(sleep_time)
 		return
 	rounds = 0
 	while rounds < total_rounds:
 		wx.Yield()
 		time.sleep(sleep_time)
 		rounds += 1
+
 #================================================================
 # performed procedure related widgets/functions
 #----------------------------------------------------------------
@@ -71,9 +74,23 @@ def manage_performed_procedures(parent=None):
 
 	if parent is None:
 		parent = wx.GetApp().GetTopWindow()
+
+	#-----------------------------------------
+	def get_tooltip(procedure=None):
+		if procedure is None:
+			return None
+		return procedure.format (
+			left_margin = 1,
+			include_episode = False,
+			include_codes = False,
+			include_address = True,
+			include_comm = True
+		)
+
 	#-----------------------------------------
 	def edit(procedure=None):
 		return edit_procedure(parent = parent, procedure = procedure)
+
 	#-----------------------------------------
 	def delete(procedure=None):
 		if gmEMRStructItems.delete_performed_procedure(procedure = procedure['pk_procedure']):
@@ -85,10 +102,10 @@ def manage_performed_procedures(parent=None):
 			beep = True
 		)
 		return False
+
 	#-----------------------------------------
 	def refresh(lctrl):
 		procs = emr.get_performed_procedures()
-
 		items = [
 			[
 				u'%s%s' % (
@@ -104,25 +121,28 @@ def manage_performed_procedures(parent=None):
 						)
 					)
 				),
+				p['performed_procedure'],
 				u'%s @ %s' % (p['unit'], p['organization']),
-				p['episode'],
-				p['performed_procedure']
+				p['episode']
 			] for p in procs
 		]
 		lctrl.set_string_items(items = items)
 		lctrl.set_data(data = procs)
+
 	#-----------------------------------------
 	gmListWidgets.get_choices_from_list (
 		parent = parent,
 		msg = _('\nSelect the procedure you want to edit !\n'),
 		caption = _('Editing performed procedures ...'),
-		columns = [_('When'), _('Where'), _('Episode'), _('Procedure')],
+		columns = [_('When'), _('Procedure'), _('Where'), _('Episode')],
 		single_selection = True,
 		edit_callback = edit,
 		new_callback = edit,
 		delete_callback = delete,
-		refresh_callback = refresh
+		refresh_callback = refresh,
+		list_tooltip_callback = get_tooltip
 	)
+
 #----------------------------------------------------------------
 def edit_procedure(parent=None, procedure=None):
 	ea = cProcedureEAPnl(parent = parent, id = -1)
@@ -135,6 +155,7 @@ def edit_procedure(parent=None, procedure=None):
 		return True
 	dlg.Destroy()
 	return False
+
 #----------------------------------------------------------------
 from Gnumed.wxGladeWidgets import wxgProcedureEAPnl
 
@@ -175,32 +196,24 @@ limit 25
 		if stay is None:
 			self._PRW_hospital_stay.SetText()
 			self._PRW_location.Enable(True)
-			self._PRW_location.display_as_disabled(False)
 			self._PRW_episode.Enable(True)
-			self._PRW_episode.display_as_disabled(False)
 			self._LBL_hospital_details.SetLabel(u'')
 		else:
 			self._PRW_location.SetText()
 			self._PRW_location.Enable(False)
-			self._PRW_location.display_as_disabled(True)
 			self._PRW_episode.SetText()
 			self._PRW_episode.Enable(False)
-			self._PRW_episode.display_as_disabled(True)
 			self._LBL_hospital_details.SetLabel(gmEMRStructItems.cHospitalStay(aPK_obj = stay).format())
 	#----------------------------------------------------------------
 	def _on_location_lost_focus(self):
 		loc = self._PRW_location.GetData()
 		if loc is None:
 			self._PRW_hospital_stay.Enable(True)
-			self._PRW_hospital_stay.display_as_disabled(False)
 			self._PRW_episode.Enable(False)
-			self._PRW_episode.display_as_disabled(True)
 		else:
 			self._PRW_hospital_stay.SetText()
 			self._PRW_hospital_stay.Enable(False)
-			self._PRW_hospital_stay.display_as_disabled(True)
 			self._PRW_episode.Enable(True)
-			self._PRW_episode.display_as_disabled(False)
 	#----------------------------------------------------------------
 	def _on_start_lost_focus(self):
 		if not self._DPRW_date.is_valid_timestamp():
@@ -383,23 +396,17 @@ limit 25
 		if self.data['pk_hospital_stay'] is None:
 			self._PRW_hospital_stay.SetText()
 			self._PRW_hospital_stay.Enable(False)
-			self._PRW_hospital_stay.display_as_disabled(True)
 			self._LBL_hospital_details.SetLabel(u'')
 			self._PRW_location.SetText(value = u'%s @ %s' % (self.data['unit'], self.data['organization']), data = self.data['pk_org_unit'])
 			self._PRW_location.Enable(True)
-			self._PRW_location.display_as_disabled(False)
 			self._PRW_episode.Enable(True)
-			self._PRW_episode.display_as_disabled(False)
 		else:
 			self._PRW_hospital_stay.SetText(value = u'%s @ %s' % (self.data['unit'], self.data['organization']), data = self.data['pk_hospital_stay'])
 			self._PRW_hospital_stay.Enable(True)
-			self._PRW_hospital_stay.display_as_disabled(False)
 			self._LBL_hospital_details.SetLabel(gmEMRStructItems.cHospitalStay(aPK_obj = self.data['pk_hospital_stay']).format())
 			self._PRW_location.SetText()
 			self._PRW_location.Enable(False)
-			self._PRW_location.display_as_disabled(True)
 			self._PRW_episode.Enable(False)
-			self._PRW_episode.display_as_disabled(True)
 
 		val, data = self._PRW_codes.generic_linked_codes2item_dict(self.data.generic_codes)
 		self._PRW_codes.SetText(val, data)
@@ -414,23 +421,17 @@ limit 25
 		if self.data['pk_hospital_stay'] is None:
 			self._PRW_hospital_stay.SetText()
 			self._PRW_hospital_stay.Enable(False)
-			self._PRW_hospital_stay.display_as_disabled(True)
 			self._LBL_hospital_details.SetLabel(u'')
 			self._PRW_location.SetText(value = u'%s @ %s' % (self.data['unit'], self.data['organization']), data = self.data['pk_org_unit'])
 			self._PRW_location.Enable(True)
-			self._PRW_location.display_as_disabled(False)
 			self._PRW_episode.Enable(True)
-			self._PRW_episode.display_as_disabled(False)
 		else:
 			self._PRW_hospital_stay.SetText(value = u'%s @ %s' % (self.data['unit'], self.data['organization']), data = self.data['pk_hospital_stay'])
 			self._PRW_hospital_stay.Enable(True)
-			self._PRW_hospital_stay.display_as_disabled(False)
 			self._LBL_hospital_details.SetLabel(gmEMRStructItems.cHospitalStay(aPK_obj = self.data['pk_hospital_stay']).format())
 			self._PRW_location.SetText()
 			self._PRW_location.Enable(False)
-			self._PRW_location.display_as_disabled(True)
 			self._PRW_episode.Enable(False)
-			self._PRW_episode.display_as_disabled(True)
 
 		self._PRW_procedure.SetFocus()
 	#----------------------------------------------------------------
@@ -1077,6 +1078,7 @@ class cEpisodeListSelectorDlg(gmListWidgets.cGenericListSelectorDlg):
 		)
 		self._LCTRL_items.set_column_widths()
 		self._LCTRL_items.set_data(data = episodes)
+
 #----------------------------------------------------------------
 class cEpisodeDescriptionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	"""Let user select an episode *description*.
@@ -1119,6 +1121,7 @@ LIMIT 30
 		)
 		gmPhraseWheel.cPhraseWheel.__init__(self, *args, **kwargs)
 		self.matcher = mp
+
 #----------------------------------------------------------------
 class cEpisodeSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	"""Let user select an episode.
@@ -1369,7 +1372,7 @@ class cEpisodeEditAreaPnl(gmEditArea.cGenericEditAreaMixin, wxgEpisodeEditAreaPn
 		if self.data is None:
 			ident = gmPerson.gmCurrentPatient()
 		else:
-			ident = gmPerson.cIdentity(aPK_obj = self.data['pk_patient'])
+			ident = gmPerson.cPerson(aPK_obj = self.data['pk_patient'])
 		self._TCTRL_patient.SetValue(ident.get_description_gender())
 		self._PRW_issue.SetText()
 		self._PRW_description.SetText()
@@ -1379,7 +1382,7 @@ class cEpisodeEditAreaPnl(gmEditArea.cGenericEditAreaMixin, wxgEpisodeEditAreaPn
 		self._PRW_codes.SetText()
 	#----------------------------------------------------------------
 	def _refresh_from_existing(self):
-		ident = gmPerson.cIdentity(aPK_obj = self.data['pk_patient'])
+		ident = gmPerson.cPerson(aPK_obj = self.data['pk_patient'])
 		self._TCTRL_patient.SetValue(ident.get_description_gender())
 
 		if self.data['pk_health_issue'] is not None:
@@ -2132,7 +2135,7 @@ if __name__ == '__main__':
 		# lauch emr dialogs test application
 #		app = testapp(0)
 #		app.MainLoop()
-#	except StandardError:
+#	except Exception:
 #		_log.exception("unhandled exception caught !")
 		# but re-raise them
 #		raise
