@@ -28,6 +28,7 @@ from Gnumed.pycommon import gmMatchProvider
 from Gnumed.business import gmEMRStructItems
 from Gnumed.business import gmPraxis
 from Gnumed.business import gmPerson
+from Gnumed.business import gmStaff
 
 from Gnumed.wxpython import gmPhraseWheel
 from Gnumed.wxpython import gmGuiHelpers
@@ -49,6 +50,76 @@ def start_new_encounter(emr=None):
 		_('Start of new encounter')
 	)
 
+#----------------------------------------------------------------
+def sanity_check_encounter_of_active_patient(parent=None, msg=None):
+
+	# FIXME: should consult a centralized security provider
+	# secretaries cannot edit encounters
+	if gmStaff.gmCurrentProvider()['role'] == u'secretary':
+		return True
+
+	pat = gmPerson.gmCurrentPatient()
+	if not pat.connected:
+		return True
+
+	dbcfg = gmCfg.cCfgSQL()
+	check_enc = bool(dbcfg.get2 (
+		option = 'encounter.show_editor_before_patient_change',
+		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
+		bias = 'user',
+		default = True					# True: if needed, not always unconditionally
+	))
+
+	if not check_enc:
+		return True
+
+	emr = pat.get_emr()
+	enc = emr.active_encounter
+
+	# did we add anything to the EMR ?
+	has_narr = enc.has_narrative()
+	has_docs = enc.has_documents()
+
+	if (not has_narr) and (not has_docs):
+		return True
+
+	empty_aoe = (gmTools.coalesce(enc['assessment_of_encounter'], '').strip() == u'')
+	zero_duration = (enc['last_affirmed'] == enc['started'])
+
+	# all is well anyway
+	if (not empty_aoe) and (not zero_duration):
+		return True
+
+	if zero_duration:
+		enc['last_affirmed'] = pydt.datetime.now(tz = gmDateTime.gmCurrentLocalTimezone)
+
+	# no narrative, presumably only import of docs and done
+	if not has_narr:
+		if empty_aoe:
+			enc['assessment_of_encounter'] = _('only documents added')
+		enc['pk_type'] = gmEMRStructItems.get_encounter_type(description = 'chart review')[0]['pk']
+		# "last_affirmed" should be latest modified_at of relevant docs but that's a lot more involved
+		enc.save_payload()
+		return True
+
+	# does have narrative
+	if empty_aoe:
+		# - work out suitable default
+		epis = emr.get_episodes_by_encounter()
+		if len(epis) > 0:
+			enc_summary = ''
+			for epi in epis:
+				enc_summary += '%s; ' % epi['description']
+			enc['assessment_of_encounter'] = enc_summary
+
+	if msg is None:
+		msg = _('Edit the encounter details of the active patient before moving on:')
+	if parent is None:
+		parent = wx.GetApp().GetTopWindow()
+	edit_encounter(parent = parent, encounter = enc, msg = msg)
+
+	return True
+
 #----------------------------------------------------------------
 def ask_for_encounter_continuation(msg=None, caption=None, encounter=None, parent=None):
 	"""This is used as the callback when the EMR detects that the
@@ -129,6 +200,8 @@ def select_encounters(parent=None, patient=None, single_selection=True, encounte
 		return False
 	#--------------------
 	def edit(enc=None):
+		if enc is None:
+			return False
 		return edit_encounter(parent = parent, encounter = enc)
 	#--------------------
 	def edit_active(enc=None):
@@ -342,7 +415,6 @@ class cEncounterEditAreaPnl(wxgEncounterEditAreaPnl.wxgEncounterEditAreaPnl):
 
 		self._PRW_encounter_type.SetText(self.__encounter['l10n_type'], data = self.__encounter['pk_type'])
 		self._PRW_location.Enable(True)
-		self._PRW_location.display_as_disabled(False)
 		branch = self.__encounter.praxis_branch
 		if branch is None:		# None or old entry because praxis has been re-configured
 			unit = self.__encounter.org_unit
@@ -350,7 +422,6 @@ class cEncounterEditAreaPnl(wxgEncounterEditAreaPnl.wxgEncounterEditAreaPnl):
 				self._PRW_location.SetText(u'', data = None)
 			else:										# old entry
 				self._PRW_location.Enable(False)
-				self._PRW_location.display_as_disabled(True)
 				self._PRW_location.SetText(_('old praxis branch: %s (%s)') % (unit['unit'], unit['organization']), data = None)
 		else:
 			self._PRW_location.SetText(self.__encounter['praxis_branch'], data = branch['pk_praxis_branch'])
@@ -575,21 +646,17 @@ class cActiveEncounterPnl(wxgActiveEncounterPnl.wxgActiveEncounterPnl):
 	def __register_events(self):
 		self._TCTRL_encounter.Bind(wx.EVT_LEFT_DCLICK, self._on_ldclick)
 
-		gmDispatcher.connect(signal = u'pre_patient_selection', receiver = self._schedule_clear)
+		gmDispatcher.connect(signal = u'pre_patient_unselection', receiver = self._on_pre_patient_unselection)
 		# this would throw an exception due to concurrency issues:
-		#gmDispatcher.connect(signal = u'post_patient_selection', receiver = self._schedule_refresh)
-		gmDispatcher.connect(signal = u'clin.episode_mod_db', receiver = self._schedule_refresh)
-		gmDispatcher.connect(signal = u'current_encounter_modified', receiver = self._schedule_refresh)
-		gmDispatcher.connect(signal = u'current_encounter_switched', receiver = self._schedule_refresh)
+		#gmDispatcher.connect(signal = u'post_patient_selection', receiver = self.refresh)
+		gmDispatcher.connect(signal = u'clin.episode_mod_db', receiver = self.refresh)
+		gmDispatcher.connect(signal = u'current_encounter_modified', receiver = self.refresh)
+		gmDispatcher.connect(signal = u'current_encounter_switched', receiver = self.refresh)
 	#------------------------------------------------------------
 	# event handler
 	#------------------------------------------------------------
-	def _schedule_clear(self):
-		wx.CallAfter(self.clear)
-	#------------------------------------------------------------
-	def _schedule_refresh(self, *args, **kwargs):
-		wx.CallAfter(self.refresh)
-		return True
+	def _on_pre_patient_unselection(self):
+		self.clear()
 	#------------------------------------------------------------
 	def _on_ldclick(self, event):
 		pat = gmPerson.gmCurrentPatient()
