@@ -65,12 +65,8 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 		pat = gmPerson.gmCurrentPatient()
 		if not pat.connected:
 			return
-		# no idea why this does not work:
-#		print "patient pk in signal:", kwargs['pk_identity']
-#		print "current patient ID:", pat.ID
-#		if kwargs['pk_identity'] == pat.ID:
-#			print "signal is about current patient"
-#			self.__on_table_mod()
+		if kwargs['pk_identity'] != pat.ID:
+			return
 		self._schedule_data_reget()
 	#--------------------------------------------------------
 	def _on_list_item_selected(self, event):
@@ -112,10 +108,11 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 		if selected_docs is None:
 			return
 		gmPerson.gmCurrentPatient().export_area.add_documents(documents = selected_docs)
+
 	#--------------------------------------------------------
 	def _on_clipboard_items_button_pressed(self, event):
 		event.Skip()
-		clip = gmGuiHelpers.clipboard2file()
+		clip = gmGuiHelpers.clipboard2file(check_for_filename = True)
 		if clip is None:
 			return
 		if clip is False:
@@ -125,6 +122,7 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 				title = _(u'Loading clipboard item (saved to file) into export area'),
 				error = _(u'Cannot add the following clip to the export area:\n%s ') % clip
 			)
+
 	#--------------------------------------------------------
 	def _on_scan_items_button_pressed(self, event):
 		event.Skip()
@@ -137,6 +135,7 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 				title = _(u'Scanning files into export area'),
 				error = _(u'Cannot add (some of) the following scans to the export area:\n%s ') % u'\n '.join(fnames)
 			)
+
 	#--------------------------------------------------------
 	def _on_remove_items_button_pressed(self, event):
 		event.Skip()
@@ -208,10 +207,11 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 					u'\n'
 					u' [%s]\n'
 					u'\n'
-					u'is not empty. Do you want to use it for saving the\n'
-					u'export area documents into, nevertheless ?\n'
+					u'already contains files. Do you still want to save the\n'
+					u'selected export area documents into that directory ?\n'
 					u'\n'
-					u'(this can be useful for including external documents)\n'
+					u'(this is useful for including the external documents\n'
+					u' already stored in or below this directory)\n'
 					u'\n'
 					u'[NO] will create a subdirectory for you and use that.'
 				) % path,
@@ -220,13 +220,24 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 			if reuse_nonempty_dir is None:
 				return True
 			if reuse_nonempty_dir is False:
-				path = gmTools.get_unique_filename (
+				path = gmTools.mk_sandbox_dir (
 					prefix = u'export-%s-' % gmPerson.gmCurrentPatient().dirname,
-					suffix = '.dir',
-					tmp_dir = path
+					base_dir = path
 				)
 
-		export_dir = gmPerson.gmCurrentPatient().export_area.export_with_meta_data(base_dir = path, items = items)
+		include_metadata = gmGuiHelpers.gm_show_question (
+			title = _(u'Saving export area documents'),
+			question = _(
+				u'Create descriptive metadata files\n'
+				u'and save them alongside the\n'
+				u'selected export area documents ?'
+			),
+			cancel_button = True
+		)
+		if include_metadata is None:
+			return True
+
+		export_dir = gmPerson.gmCurrentPatient().export_area.export(base_dir = path, items = items, with_metadata = include_metadata)
 
 		self.save_soap_note(soap = _('Saved to [%s]:\n - %s') % (
 			export_dir,
@@ -264,7 +275,7 @@ class cExportAreaPluginPnl(wxgExportAreaPluginPnl.wxgExportAreaPluginPnl, gmRege
 			if not gmTools.dir_is_empty(path2include):
 				base_dir = path2include
 
-		export_dir = gmPerson.gmCurrentPatient().export_area.export_with_meta_data(base_dir = base_dir, items = items)
+		export_dir = gmPerson.gmCurrentPatient().export_area.export(base_dir = base_dir, items = items, with_metadata = True)
 		if export_dir is None:
 			return False
 
@@ -519,15 +530,14 @@ class cPrintMgrPluginPnl(wxgPrintMgrPluginPnl.wxgPrintMgrPluginPnl, gmRegetMixin
 	def _on_table_mod(self, *args, **kwargs):
 		if kwargs['table'] != 'clin.export_item':
 			return
-#		pat = gmPerson.gmCurrentPatient()
-#		if not pat.connected:
-#			return
-		# no idea why this does not work:
-#		print "patient pk in signal:", kwargs['pk_identity']
-#		print "current patient ID:", pat.ID
-#		if kwargs['pk_identity'] == pat.ID:
-#			print "signal is about current patient"
-#			self.__on_table_mod()
+		if self._RBTN_all_patients.Value is True:
+			self._schedule_data_reget()
+			return
+		pat = gmPerson.gmCurrentPatient()
+		if not pat.connected:
+			return
+		if kwargs['pk_identity'] != pat.ID:
+			return
 		self._schedule_data_reget()
 	#--------------------------------------------------------
 	def _on_all_patients_selected(self, event):
@@ -599,11 +609,6 @@ class cPrintMgrPluginPnl(wxgPrintMgrPluginPnl.wxgPrintMgrPluginPnl, gmRegetMixin
 		self._BTN_export_printouts.Enable(False)
 	#--------------------------------------------------------
 	# reget mixin API
-	#
-	# remember to call
-	#	self._schedule_data_reget()
-	# whenever you learn of data changes from database
-	# listener threads, dispatcher signals etc.
 	#--------------------------------------------------------
 	def _populate_with_data(self):
 		if self._RBTN_all_patients.Value is True:
